==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/userSession/HotRodUserSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.userSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodUserSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.UserSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.HotRodUserSessionEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/userSession/HotRodUserSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.userSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodUserSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.UserSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodUserSessionEntity.HotRodUserSessionEntitySchema.INSTANCE;
    }
}
